# coding: utf-8

"""
    document-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_document_service.configuration import Configuration


class Document(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'title': 'str',
        'author': 'str',
        'summary': 'str',
        'description': 'str',
        'language': 'str',
        'keywords': 'str',
        'data_id': 'str',
        'format': 'str',
        'modified_time': 'datetime',
        'data_storage': 'str',
        'version': 'str',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'author': 'author',
        'summary': 'summary',
        'description': 'description',
        'language': 'language',
        'keywords': 'keywords',
        'data_id': 'dataId',
        'format': 'format',
        'modified_time': 'modifiedTime',
        'data_storage': 'dataStorage',
        'version': 'version',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, title=None, author=None, summary=None, description=None, language=None, keywords=None, data_id=None, format=None, modified_time=None, data_storage=None, version=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """Document - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._title = None
        self._author = None
        self._summary = None
        self._description = None
        self._language = None
        self._keywords = None
        self._data_id = None
        self._format = None
        self._modified_time = None
        self._data_storage = None
        self._version = None
        self._tenant_id = None
        self.discriminator = None

        self.id = id
        self.title = title
        self.author = author
        self.summary = summary
        self.description = description
        self.language = language
        self.keywords = keywords
        self.data_id = data_id
        self.format = format
        self.modified_time = modified_time
        self.data_storage = data_storage
        if version is not None:
            self.version = version
        self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this Document.  # noqa: E501


        :return: The id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Document.


        :param id: The id of this Document.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def title(self):
        """Gets the title of this Document.  # noqa: E501


        :return: The title of this Document.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Document.


        :param title: The title of this Document.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and title is None:  # noqa: E501
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                title is not None and len(title) > 255):
            raise ValueError("Invalid value for `title`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                title is not None and len(title) < 0):
            raise ValueError("Invalid value for `title`, length must be greater than or equal to `0`")  # noqa: E501

        self._title = title

    @property
    def author(self):
        """Gets the author of this Document.  # noqa: E501


        :return: The author of this Document.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this Document.


        :param author: The author of this Document.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and author is None:  # noqa: E501
            raise ValueError("Invalid value for `author`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                author is not None and len(author) > 255):
            raise ValueError("Invalid value for `author`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                author is not None and len(author) < 0):
            raise ValueError("Invalid value for `author`, length must be greater than or equal to `0`")  # noqa: E501

        self._author = author

    @property
    def summary(self):
        """Gets the summary of this Document.  # noqa: E501


        :return: The summary of this Document.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Document.


        :param summary: The summary of this Document.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                summary is not None and len(summary) > 8000):
            raise ValueError("Invalid value for `summary`, length must be less than or equal to `8000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                summary is not None and len(summary) < 0):
            raise ValueError("Invalid value for `summary`, length must be greater than or equal to `0`")  # noqa: E501

        self._summary = summary

    @property
    def description(self):
        """Gets the description of this Document.  # noqa: E501


        :return: The description of this Document.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Document.


        :param description: The description of this Document.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 8000):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `8000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def language(self):
        """Gets the language of this Document.  # noqa: E501


        :return: The language of this Document.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Document.


        :param language: The language of this Document.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                language is not None and len(language) > 50):
            raise ValueError("Invalid value for `language`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                language is not None and len(language) < 0):
            raise ValueError("Invalid value for `language`, length must be greater than or equal to `0`")  # noqa: E501

        self._language = language

    @property
    def keywords(self):
        """Gets the keywords of this Document.  # noqa: E501


        :return: The keywords of this Document.  # noqa: E501
        :rtype: str
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this Document.


        :param keywords: The keywords of this Document.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                keywords is not None and len(keywords) > 1024):
            raise ValueError("Invalid value for `keywords`, length must be less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                keywords is not None and len(keywords) < 0):
            raise ValueError("Invalid value for `keywords`, length must be greater than or equal to `0`")  # noqa: E501

        self._keywords = keywords

    @property
    def data_id(self):
        """Gets the data_id of this Document.  # noqa: E501


        :return: The data_id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._data_id

    @data_id.setter
    def data_id(self, data_id):
        """Sets the data_id of this Document.


        :param data_id: The data_id of this Document.  # noqa: E501
        :type: str
        """

        self._data_id = data_id

    @property
    def format(self):
        """Gets the format of this Document.  # noqa: E501


        :return: The format of this Document.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Document.


        :param format: The format of this Document.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and format is None:  # noqa: E501
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                format is not None and len(format) > 50):
            raise ValueError("Invalid value for `format`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                format is not None and len(format) < 0):
            raise ValueError("Invalid value for `format`, length must be greater than or equal to `0`")  # noqa: E501

        self._format = format

    @property
    def modified_time(self):
        """Gets the modified_time of this Document.  # noqa: E501


        :return: The modified_time of this Document.  # noqa: E501
        :rtype: datetime
        """
        return self._modified_time

    @modified_time.setter
    def modified_time(self, modified_time):
        """Sets the modified_time of this Document.


        :param modified_time: The modified_time of this Document.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and modified_time is None:  # noqa: E501
            raise ValueError("Invalid value for `modified_time`, must not be `None`")  # noqa: E501

        self._modified_time = modified_time

    @property
    def data_storage(self):
        """Gets the data_storage of this Document.  # noqa: E501


        :return: The data_storage of this Document.  # noqa: E501
        :rtype: str
        """
        return self._data_storage

    @data_storage.setter
    def data_storage(self, data_storage):
        """Sets the data_storage of this Document.


        :param data_storage: The data_storage of this Document.  # noqa: E501
        :type: str
        """

        self._data_storage = data_storage

    @property
    def version(self):
        """Gets the version of this Document.  # noqa: E501


        :return: The version of this Document.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Document.


        :param version: The version of this Document.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def tenant_id(self):
        """Gets the tenant_id of this Document.  # noqa: E501


        :return: The tenant_id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this Document.


        :param tenant_id: The tenant_id of this Document.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Document):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class FactoryConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'qmax': 'float',
        'qmin': 'float',
        'rate_of_change_sum_range_set_value1': 'float',
        'rate_of_change_sum_range_set_value2': 'float',
        'rate_of_change_sum_range_set_value3': 'float',
        'rate_of_change_sum_range_set_value4': 'float',
        'pump_station_feedback_increase_value1': 'float',
        'pump_station_feedback_increase_value2': 'float',
        'pump_station_feedback_increase_value3': 'float',
        'pump_station_feedback_increase_value4': 'float',
        'pump_station_feedback_increase_value5': 'float',
        'flow_change_value': 'float'
    }

    attribute_map = {
        'qmax': 'qmax',
        'qmin': 'qmin',
        'rate_of_change_sum_range_set_value1': 'rateOfChangeSumRangeSetValue1',
        'rate_of_change_sum_range_set_value2': 'rateOfChangeSumRangeSetValue2',
        'rate_of_change_sum_range_set_value3': 'rateOfChangeSumRangeSetValue3',
        'rate_of_change_sum_range_set_value4': 'rateOfChangeSumRangeSetValue4',
        'pump_station_feedback_increase_value1': 'pumpStationFeedbackIncreaseValue1',
        'pump_station_feedback_increase_value2': 'pumpStationFeedbackIncreaseValue2',
        'pump_station_feedback_increase_value3': 'pumpStationFeedbackIncreaseValue3',
        'pump_station_feedback_increase_value4': 'pumpStationFeedbackIncreaseValue4',
        'pump_station_feedback_increase_value5': 'pumpStationFeedbackIncreaseValue5',
        'flow_change_value': 'flowChangeValue'
    }

    def __init__(self, qmax=None, qmin=None, rate_of_change_sum_range_set_value1=None, rate_of_change_sum_range_set_value2=None, rate_of_change_sum_range_set_value3=None, rate_of_change_sum_range_set_value4=None, pump_station_feedback_increase_value1=None, pump_station_feedback_increase_value2=None, pump_station_feedback_increase_value3=None, pump_station_feedback_increase_value4=None, pump_station_feedback_increase_value5=None, flow_change_value=None, local_vars_configuration=None):  # noqa: E501
        """FactoryConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._qmax = None
        self._qmin = None
        self._rate_of_change_sum_range_set_value1 = None
        self._rate_of_change_sum_range_set_value2 = None
        self._rate_of_change_sum_range_set_value3 = None
        self._rate_of_change_sum_range_set_value4 = None
        self._pump_station_feedback_increase_value1 = None
        self._pump_station_feedback_increase_value2 = None
        self._pump_station_feedback_increase_value3 = None
        self._pump_station_feedback_increase_value4 = None
        self._pump_station_feedback_increase_value5 = None
        self._flow_change_value = None
        self.discriminator = None

        if qmax is not None:
            self.qmax = qmax
        if qmin is not None:
            self.qmin = qmin
        if rate_of_change_sum_range_set_value1 is not None:
            self.rate_of_change_sum_range_set_value1 = rate_of_change_sum_range_set_value1
        if rate_of_change_sum_range_set_value2 is not None:
            self.rate_of_change_sum_range_set_value2 = rate_of_change_sum_range_set_value2
        if rate_of_change_sum_range_set_value3 is not None:
            self.rate_of_change_sum_range_set_value3 = rate_of_change_sum_range_set_value3
        if rate_of_change_sum_range_set_value4 is not None:
            self.rate_of_change_sum_range_set_value4 = rate_of_change_sum_range_set_value4
        if pump_station_feedback_increase_value1 is not None:
            self.pump_station_feedback_increase_value1 = pump_station_feedback_increase_value1
        if pump_station_feedback_increase_value2 is not None:
            self.pump_station_feedback_increase_value2 = pump_station_feedback_increase_value2
        if pump_station_feedback_increase_value3 is not None:
            self.pump_station_feedback_increase_value3 = pump_station_feedback_increase_value3
        if pump_station_feedback_increase_value4 is not None:
            self.pump_station_feedback_increase_value4 = pump_station_feedback_increase_value4
        if pump_station_feedback_increase_value5 is not None:
            self.pump_station_feedback_increase_value5 = pump_station_feedback_increase_value5
        if flow_change_value is not None:
            self.flow_change_value = flow_change_value

    @property
    def qmax(self):
        """Gets the qmax of this FactoryConfig.  # noqa: E501


        :return: The qmax of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._qmax

    @qmax.setter
    def qmax(self, qmax):
        """Sets the qmax of this FactoryConfig.


        :param qmax: The qmax of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._qmax = qmax

    @property
    def qmin(self):
        """Gets the qmin of this FactoryConfig.  # noqa: E501


        :return: The qmin of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._qmin

    @qmin.setter
    def qmin(self, qmin):
        """Sets the qmin of this FactoryConfig.


        :param qmin: The qmin of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._qmin = qmin

    @property
    def rate_of_change_sum_range_set_value1(self):
        """Gets the rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value1

    @rate_of_change_sum_range_set_value1.setter
    def rate_of_change_sum_range_set_value1(self, rate_of_change_sum_range_set_value1):
        """Sets the rate_of_change_sum_range_set_value1 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value1: The rate_of_change_sum_range_set_value1 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value1 = rate_of_change_sum_range_set_value1

    @property
    def rate_of_change_sum_range_set_value2(self):
        """Gets the rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value2

    @rate_of_change_sum_range_set_value2.setter
    def rate_of_change_sum_range_set_value2(self, rate_of_change_sum_range_set_value2):
        """Sets the rate_of_change_sum_range_set_value2 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value2: The rate_of_change_sum_range_set_value2 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value2 = rate_of_change_sum_range_set_value2

    @property
    def rate_of_change_sum_range_set_value3(self):
        """Gets the rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value3

    @rate_of_change_sum_range_set_value3.setter
    def rate_of_change_sum_range_set_value3(self, rate_of_change_sum_range_set_value3):
        """Sets the rate_of_change_sum_range_set_value3 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value3: The rate_of_change_sum_range_set_value3 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value3 = rate_of_change_sum_range_set_value3

    @property
    def rate_of_change_sum_range_set_value4(self):
        """Gets the rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501


        :return: The rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._rate_of_change_sum_range_set_value4

    @rate_of_change_sum_range_set_value4.setter
    def rate_of_change_sum_range_set_value4(self, rate_of_change_sum_range_set_value4):
        """Sets the rate_of_change_sum_range_set_value4 of this FactoryConfig.


        :param rate_of_change_sum_range_set_value4: The rate_of_change_sum_range_set_value4 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._rate_of_change_sum_range_set_value4 = rate_of_change_sum_range_set_value4

    @property
    def pump_station_feedback_increase_value1(self):
        """Gets the pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value1

    @pump_station_feedback_increase_value1.setter
    def pump_station_feedback_increase_value1(self, pump_station_feedback_increase_value1):
        """Sets the pump_station_feedback_increase_value1 of this FactoryConfig.


        :param pump_station_feedback_increase_value1: The pump_station_feedback_increase_value1 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value1 = pump_station_feedback_increase_value1

    @property
    def pump_station_feedback_increase_value2(self):
        """Gets the pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value2

    @pump_station_feedback_increase_value2.setter
    def pump_station_feedback_increase_value2(self, pump_station_feedback_increase_value2):
        """Sets the pump_station_feedback_increase_value2 of this FactoryConfig.


        :param pump_station_feedback_increase_value2: The pump_station_feedback_increase_value2 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value2 = pump_station_feedback_increase_value2

    @property
    def pump_station_feedback_increase_value3(self):
        """Gets the pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value3

    @pump_station_feedback_increase_value3.setter
    def pump_station_feedback_increase_value3(self, pump_station_feedback_increase_value3):
        """Sets the pump_station_feedback_increase_value3 of this FactoryConfig.


        :param pump_station_feedback_increase_value3: The pump_station_feedback_increase_value3 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value3 = pump_station_feedback_increase_value3

    @property
    def pump_station_feedback_increase_value4(self):
        """Gets the pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value4

    @pump_station_feedback_increase_value4.setter
    def pump_station_feedback_increase_value4(self, pump_station_feedback_increase_value4):
        """Sets the pump_station_feedback_increase_value4 of this FactoryConfig.


        :param pump_station_feedback_increase_value4: The pump_station_feedback_increase_value4 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value4 = pump_station_feedback_increase_value4

    @property
    def pump_station_feedback_increase_value5(self):
        """Gets the pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501


        :return: The pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._pump_station_feedback_increase_value5

    @pump_station_feedback_increase_value5.setter
    def pump_station_feedback_increase_value5(self, pump_station_feedback_increase_value5):
        """Sets the pump_station_feedback_increase_value5 of this FactoryConfig.


        :param pump_station_feedback_increase_value5: The pump_station_feedback_increase_value5 of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._pump_station_feedback_increase_value5 = pump_station_feedback_increase_value5

    @property
    def flow_change_value(self):
        """Gets the flow_change_value of this FactoryConfig.  # noqa: E501


        :return: The flow_change_value of this FactoryConfig.  # noqa: E501
        :rtype: float
        """
        return self._flow_change_value

    @flow_change_value.setter
    def flow_change_value(self, flow_change_value):
        """Sets the flow_change_value of this FactoryConfig.


        :param flow_change_value: The flow_change_value of this FactoryConfig.  # noqa: E501
        :type: float
        """

        self._flow_change_value = flow_change_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FactoryConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FactoryConfig):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_wd_domain_service.api.accident_api import AccidentApi
from dhicn_wd_domain_service.api.accuracy_config_api import AccuracyConfigApi
from dhicn_wd_domain_service.api.alarm_config_api import AlarmConfigApi
from dhicn_wd_domain_service.api.alarm_log_api import AlarmLogApi
from dhicn_wd_domain_service.api.document_api import DocumentApi
from dhicn_wd_domain_service.api.gis_api import GISApi
from dhicn_wd_domain_service.api.indicator_config_api import IndicatorConfigApi
from dhicn_wd_domain_service.api.online_api import OnlineApi
from dhicn_wd_domain_service.api.pipe_risk_api import PipeRiskApi
from dhicn_wd_domain_service.api.scenario_compute_api import ScenarioComputeApi
from dhicn_wd_domain_service.api.schedule_api import ScheduleApi
from dhicn_wd_domain_service.api.statistic_api import StatisticApi
from dhicn_wd_domain_service.api.valve_config_api import ValveConfigApi



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wd_domain_service.api_client import ApiClient
from dhicn_wd_domain_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PipeRiskApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_domain_wd_config_pipe_risk_calculate_get(self, **kwargs):  # noqa: E501
        """爆管风险计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_calculate_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_calculate_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_calculate_get_with_http_info(self, **kwargs):  # noqa: E501
        """爆管风险计算  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_calculate_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_calculate_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/calculate', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_get_length_percent_get(self, **kwargs):  # noqa: E501
        """获取各风险等级管道长度所占全管道长度比例  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_get_length_percent_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Int32DoubleKeyValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_get_length_percent_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_get_length_percent_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取各风险等级管道长度所占全管道长度比例  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_get_length_percent_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Int32DoubleKeyValue], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_get_length_percent_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/get-length-percent', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Int32DoubleKeyValue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_para_add_post(self, **kwargs):  # noqa: E501
        """批量新增爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddBrokenPipeRiskParaCfgInput] add_broken_pipe_risk_para_cfg_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_para_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_para_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量新增爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddBrokenPipeRiskParaCfgInput] add_broken_pipe_risk_para_cfg_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_broken_pipe_risk_para_cfg_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_para_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_broken_pipe_risk_para_cfg_input' in local_var_params:
            body_params = local_var_params['add_broken_pipe_risk_para_cfg_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/para/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_para_delete_post(self, **kwargs):  # noqa: E501
        """删除参数配置信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_para_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_para_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除参数配置信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_para_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/para/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get(self, **kwargs):  # noqa: E501
        """根据权重Id获取爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str risk_weight_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PipeRiskParamOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get_with_http_info(self, **kwargs):  # noqa: E501
        """根据权重Id获取爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str risk_weight_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PipeRiskParamOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'risk_weight_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_para_get_by_weight_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'risk_weight_id' in local_var_params and local_var_params['risk_weight_id'] is not None:  # noqa: E501
            query_params.append(('riskWeightId', local_var_params['risk_weight_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/para/get-by-weight-id', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PipeRiskParamOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_para_update_post(self, **kwargs):  # noqa: E501
        """更新爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskParamInput] update_pipe_risk_param_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_para_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_para_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新爆管风险参数信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_para_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskParamInput] update_pipe_risk_param_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_pipe_risk_param_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_para_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_pipe_risk_param_input' in local_var_params:
            body_params = local_var_params['update_pipe_risk_param_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/para/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get(self, **kwargs):  # noqa: E501
        """获取各个等级的风险管道信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Int32ModelPipeInfoListKeyValue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取各个等级的风险管道信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Int32ModelPipeInfoListKeyValue], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_result_get_classify_pipes_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/result/get-classify-pipes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Int32ModelPipeInfoListKeyValue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get(self, **kwargs):  # noqa: E501
        """获取高爆管风险管道信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ModelPipeInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取高爆管风险管道信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ModelPipeInfo], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_result_get_highrisk_pipes_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/result/get-highrisk-pipes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ModelPipeInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_risk_property_add_post(self, **kwargs):  # noqa: E501
        """新增管道风险相关属性信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskPropertyInput] add_pipe_risk_property_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_risk_property_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_risk_property_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """新增管道风险相关属性信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskPropertyInput] add_pipe_risk_property_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_pipe_risk_property_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_risk_property_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_pipe_risk_property_input' in local_var_params:
            body_params = local_var_params['add_pipe_risk_property_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/risk-property/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_risk_property_all_get(self, **kwargs):  # noqa: E501
        """获取所有爆管相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_all_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PipeRiskPropertyOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_risk_property_all_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_risk_property_all_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有爆管相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_all_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PipeRiskPropertyOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_risk_property_all_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/risk-property/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PipeRiskPropertyOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_risk_property_delete_post(self, **kwargs):  # noqa: E501
        """删除管道风险相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_risk_property_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_risk_property_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除管道风险相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_risk_property_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/risk-property/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_risk_property_resave_post(self, **kwargs):  # noqa: E501
        """重新保存所有爆管相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_resave_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskPropertyInput] add_pipe_risk_property_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_risk_property_resave_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_risk_property_resave_post_with_http_info(self, **kwargs):  # noqa: E501
        """重新保存所有爆管相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_resave_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskPropertyInput] add_pipe_risk_property_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_pipe_risk_property_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_risk_property_resave_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_pipe_risk_property_input' in local_var_params:
            body_params = local_var_params['add_pipe_risk_property_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/risk-property/resave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_risk_property_update_post(self, **kwargs):  # noqa: E501
        """更新管道风险相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskPropertyInput] update_pipe_risk_property_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_risk_property_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_risk_property_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新管道风险相关属性  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_risk_property_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskPropertyInput] update_pipe_risk_property_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_pipe_risk_property_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_risk_property_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_pipe_risk_property_input' in local_var_params:
            body_params = local_var_params['update_pipe_risk_property_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/risk-property/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_weight_add_post(self, **kwargs):  # noqa: E501
        """批量新增爆管风险权重  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskWeightInput] add_pipe_risk_weight_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_weight_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_weight_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量新增爆管风险权重  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AddPipeRiskWeightInput] add_pipe_risk_weight_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_pipe_risk_weight_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_weight_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_pipe_risk_weight_input' in local_var_params:
            body_params = local_var_params['add_pipe_risk_weight_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/weight/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_weight_all_get(self, **kwargs):  # noqa: E501
        """获取所有爆管风险权重信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_all_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PipeRiskWeightOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_weight_all_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_weight_all_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有爆管风险权重信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_all_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PipeRiskWeightOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_weight_all_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/weight/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PipeRiskWeightOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_weight_delete_post(self, **kwargs):  # noqa: E501
        """删除权重信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_weight_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_weight_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除权重信息  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_weight_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/weight/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_domain_wd_config_pipe_risk_weight_update_post(self, **kwargs):  # noqa: E501
        """更新爆管风险权重  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskWeightInput] update_pipe_risk_weight_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_domain_wd_config_pipe_risk_weight_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_domain_wd_config_pipe_risk_weight_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新爆管风险权重  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_domain_wd_config_pipe_risk_weight_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[UpdatePipeRiskWeightInput] update_pipe_risk_weight_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_pipe_risk_weight_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_domain_wd_config_pipe_risk_weight_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_pipe_risk_weight_input' in local_var_params:
            body_params = local_var_params['update_pipe_risk_weight_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/domain-wd/config/pipe-risk/weight/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class AssemblyConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sys_input_output_code_configs': 'list[SysCodeConfigInputOutput]',
        'mapping_dic': 'dict(str, object)',
        'online_point_dic': 'dict(str, object)',
        'model_nodes_dic': 'dict(str, object)'
    }

    attribute_map = {
        'sys_input_output_code_configs': 'sysInputOutputCodeConfigs',
        'mapping_dic': 'mappingDic',
        'online_point_dic': 'onlinePointDic',
        'model_nodes_dic': 'modelNodesDic'
    }

    def __init__(self, sys_input_output_code_configs=None, mapping_dic=None, online_point_dic=None, model_nodes_dic=None, local_vars_configuration=None):  # noqa: E501
        """AssemblyConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sys_input_output_code_configs = None
        self._mapping_dic = None
        self._online_point_dic = None
        self._model_nodes_dic = None
        self.discriminator = None

        self.sys_input_output_code_configs = sys_input_output_code_configs
        self.mapping_dic = mapping_dic
        self.online_point_dic = online_point_dic
        self.model_nodes_dic = model_nodes_dic

    @property
    def sys_input_output_code_configs(self):
        """Gets the sys_input_output_code_configs of this AssemblyConfig.  # noqa: E501


        :return: The sys_input_output_code_configs of this AssemblyConfig.  # noqa: E501
        :rtype: list[SysCodeConfigInputOutput]
        """
        return self._sys_input_output_code_configs

    @sys_input_output_code_configs.setter
    def sys_input_output_code_configs(self, sys_input_output_code_configs):
        """Sets the sys_input_output_code_configs of this AssemblyConfig.


        :param sys_input_output_code_configs: The sys_input_output_code_configs of this AssemblyConfig.  # noqa: E501
        :type: list[SysCodeConfigInputOutput]
        """

        self._sys_input_output_code_configs = sys_input_output_code_configs

    @property
    def mapping_dic(self):
        """Gets the mapping_dic of this AssemblyConfig.  # noqa: E501


        :return: The mapping_dic of this AssemblyConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._mapping_dic

    @mapping_dic.setter
    def mapping_dic(self, mapping_dic):
        """Sets the mapping_dic of this AssemblyConfig.


        :param mapping_dic: The mapping_dic of this AssemblyConfig.  # noqa: E501
        :type: dict(str, object)
        """

        self._mapping_dic = mapping_dic

    @property
    def online_point_dic(self):
        """Gets the online_point_dic of this AssemblyConfig.  # noqa: E501


        :return: The online_point_dic of this AssemblyConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._online_point_dic

    @online_point_dic.setter
    def online_point_dic(self, online_point_dic):
        """Sets the online_point_dic of this AssemblyConfig.


        :param online_point_dic: The online_point_dic of this AssemblyConfig.  # noqa: E501
        :type: dict(str, object)
        """

        self._online_point_dic = online_point_dic

    @property
    def model_nodes_dic(self):
        """Gets the model_nodes_dic of this AssemblyConfig.  # noqa: E501


        :return: The model_nodes_dic of this AssemblyConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._model_nodes_dic

    @model_nodes_dic.setter
    def model_nodes_dic(self, model_nodes_dic):
        """Sets the model_nodes_dic of this AssemblyConfig.


        :param model_nodes_dic: The model_nodes_dic of this AssemblyConfig.  # noqa: E501
        :type: dict(str, object)
        """

        self._model_nodes_dic = model_nodes_dic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssemblyConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssemblyConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class AssemblyConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'sys_code_config': 'SysCodeConfigInputOutput',
        'online_point_config': 'OnlinePointConfigInputOutput',
        'model_node_config': 'ModelNodeConfigInputOutput',
        'mapping_config': 'MappingConfigInputOutput'
    }

    attribute_map = {
        'sys_code_config': 'sysCodeConfig',
        'online_point_config': 'onlinePointConfig',
        'model_node_config': 'modelNodeConfig',
        'mapping_config': 'mappingConfig'
    }

    def __init__(self, sys_code_config=None, online_point_config=None, model_node_config=None, mapping_config=None, local_vars_configuration=None):  # noqa: E501
        """AssemblyConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._sys_code_config = None
        self._online_point_config = None
        self._model_node_config = None
        self._mapping_config = None
        self.discriminator = None

        if sys_code_config is not None:
            self.sys_code_config = sys_code_config
        if online_point_config is not None:
            self.online_point_config = online_point_config
        if model_node_config is not None:
            self.model_node_config = model_node_config
        if mapping_config is not None:
            self.mapping_config = mapping_config

    @property
    def sys_code_config(self):
        """Gets the sys_code_config of this AssemblyConfigOutput.  # noqa: E501


        :return: The sys_code_config of this AssemblyConfigOutput.  # noqa: E501
        :rtype: SysCodeConfigInputOutput
        """
        return self._sys_code_config

    @sys_code_config.setter
    def sys_code_config(self, sys_code_config):
        """Sets the sys_code_config of this AssemblyConfigOutput.


        :param sys_code_config: The sys_code_config of this AssemblyConfigOutput.  # noqa: E501
        :type: SysCodeConfigInputOutput
        """

        self._sys_code_config = sys_code_config

    @property
    def online_point_config(self):
        """Gets the online_point_config of this AssemblyConfigOutput.  # noqa: E501


        :return: The online_point_config of this AssemblyConfigOutput.  # noqa: E501
        :rtype: OnlinePointConfigInputOutput
        """
        return self._online_point_config

    @online_point_config.setter
    def online_point_config(self, online_point_config):
        """Sets the online_point_config of this AssemblyConfigOutput.


        :param online_point_config: The online_point_config of this AssemblyConfigOutput.  # noqa: E501
        :type: OnlinePointConfigInputOutput
        """

        self._online_point_config = online_point_config

    @property
    def model_node_config(self):
        """Gets the model_node_config of this AssemblyConfigOutput.  # noqa: E501


        :return: The model_node_config of this AssemblyConfigOutput.  # noqa: E501
        :rtype: ModelNodeConfigInputOutput
        """
        return self._model_node_config

    @model_node_config.setter
    def model_node_config(self, model_node_config):
        """Sets the model_node_config of this AssemblyConfigOutput.


        :param model_node_config: The model_node_config of this AssemblyConfigOutput.  # noqa: E501
        :type: ModelNodeConfigInputOutput
        """

        self._model_node_config = model_node_config

    @property
    def mapping_config(self):
        """Gets the mapping_config of this AssemblyConfigOutput.  # noqa: E501


        :return: The mapping_config of this AssemblyConfigOutput.  # noqa: E501
        :rtype: MappingConfigInputOutput
        """
        return self._mapping_config

    @mapping_config.setter
    def mapping_config(self, mapping_config):
        """Sets the mapping_config of this AssemblyConfigOutput.


        :param mapping_config: The mapping_config of this AssemblyConfigOutput.  # noqa: E501
        :type: MappingConfigInputOutput
        """

        self._mapping_config = mapping_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssemblyConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssemblyConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class DosingStatisticDailysOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'point_code': 'str',
        'point_name': 'str',
        'unit': 'str',
        'max_value': 'float',
        'min_value': 'float',
        'avg_value': 'float',
        'last_value': 'float',
        'first_value': 'float',
        'sum_value': 'float',
        'ts_data': 'list[TsPair1]'
    }

    attribute_map = {
        'point_code': 'pointCode',
        'point_name': 'pointName',
        'unit': 'unit',
        'max_value': 'maxValue',
        'min_value': 'minValue',
        'avg_value': 'avgValue',
        'last_value': 'lastValue',
        'first_value': 'firstValue',
        'sum_value': 'sumValue',
        'ts_data': 'tsData'
    }

    def __init__(self, point_code=None, point_name=None, unit=None, max_value=None, min_value=None, avg_value=None, last_value=None, first_value=None, sum_value=None, ts_data=None, local_vars_configuration=None):  # noqa: E501
        """DosingStatisticDailysOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._point_code = None
        self._point_name = None
        self._unit = None
        self._max_value = None
        self._min_value = None
        self._avg_value = None
        self._last_value = None
        self._first_value = None
        self._sum_value = None
        self._ts_data = None
        self.discriminator = None

        self.point_code = point_code
        self.point_name = point_name
        self.unit = unit
        if max_value is not None:
            self.max_value = max_value
        if min_value is not None:
            self.min_value = min_value
        if avg_value is not None:
            self.avg_value = avg_value
        if last_value is not None:
            self.last_value = last_value
        if first_value is not None:
            self.first_value = first_value
        if sum_value is not None:
            self.sum_value = sum_value
        self.ts_data = ts_data

    @property
    def point_code(self):
        """Gets the point_code of this DosingStatisticDailysOutput.  # noqa: E501

        统计项代码 statistic item code  # noqa: E501

        :return: The point_code of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_code

    @point_code.setter
    def point_code(self, point_code):
        """Sets the point_code of this DosingStatisticDailysOutput.

        统计项代码 statistic item code  # noqa: E501

        :param point_code: The point_code of this DosingStatisticDailysOutput.  # noqa: E501
        :type: str
        """

        self._point_code = point_code

    @property
    def point_name(self):
        """Gets the point_name of this DosingStatisticDailysOutput.  # noqa: E501

        统计项名称 statistic item name  # noqa: E501

        :return: The point_name of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_name

    @point_name.setter
    def point_name(self, point_name):
        """Sets the point_name of this DosingStatisticDailysOutput.

        统计项名称 statistic item name  # noqa: E501

        :param point_name: The point_name of this DosingStatisticDailysOutput.  # noqa: E501
        :type: str
        """

        self._point_name = point_name

    @property
    def unit(self):
        """Gets the unit of this DosingStatisticDailysOutput.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this DosingStatisticDailysOutput.

        单位 unit  # noqa: E501

        :param unit: The unit of this DosingStatisticDailysOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def max_value(self):
        """Gets the max_value of this DosingStatisticDailysOutput.  # noqa: E501

        最大值 maximum value  # noqa: E501

        :return: The max_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this DosingStatisticDailysOutput.

        最大值 maximum value  # noqa: E501

        :param max_value: The max_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def min_value(self):
        """Gets the min_value of this DosingStatisticDailysOutput.  # noqa: E501

        最小值 minimum value  # noqa: E501

        :return: The min_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this DosingStatisticDailysOutput.

        最小值 minimum value  # noqa: E501

        :param min_value: The min_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def avg_value(self):
        """Gets the avg_value of this DosingStatisticDailysOutput.  # noqa: E501

        平均值 average value  # noqa: E501

        :return: The avg_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._avg_value

    @avg_value.setter
    def avg_value(self, avg_value):
        """Sets the avg_value of this DosingStatisticDailysOutput.

        平均值 average value  # noqa: E501

        :param avg_value: The avg_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._avg_value = avg_value

    @property
    def last_value(self):
        """Gets the last_value of this DosingStatisticDailysOutput.  # noqa: E501

        最后一个值 last value  # noqa: E501

        :return: The last_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._last_value

    @last_value.setter
    def last_value(self, last_value):
        """Sets the last_value of this DosingStatisticDailysOutput.

        最后一个值 last value  # noqa: E501

        :param last_value: The last_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._last_value = last_value

    @property
    def first_value(self):
        """Gets the first_value of this DosingStatisticDailysOutput.  # noqa: E501

        第一个值 first value  # noqa: E501

        :return: The first_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._first_value

    @first_value.setter
    def first_value(self, first_value):
        """Sets the first_value of this DosingStatisticDailysOutput.

        第一个值 first value  # noqa: E501

        :param first_value: The first_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._first_value = first_value

    @property
    def sum_value(self):
        """Gets the sum_value of this DosingStatisticDailysOutput.  # noqa: E501

        累计值 sum value  # noqa: E501

        :return: The sum_value of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: float
        """
        return self._sum_value

    @sum_value.setter
    def sum_value(self, sum_value):
        """Sets the sum_value of this DosingStatisticDailysOutput.

        累计值 sum value  # noqa: E501

        :param sum_value: The sum_value of this DosingStatisticDailysOutput.  # noqa: E501
        :type: float
        """

        self._sum_value = sum_value

    @property
    def ts_data(self):
        """Gets the ts_data of this DosingStatisticDailysOutput.  # noqa: E501

        时间序列 time-series data  # noqa: E501

        :return: The ts_data of this DosingStatisticDailysOutput.  # noqa: E501
        :rtype: list[TsPair1]
        """
        return self._ts_data

    @ts_data.setter
    def ts_data(self, ts_data):
        """Sets the ts_data of this DosingStatisticDailysOutput.

        时间序列 time-series data  # noqa: E501

        :param ts_data: The ts_data of this DosingStatisticDailysOutput.  # noqa: E501
        :type: list[TsPair1]
        """

        self._ts_data = ts_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosingStatisticDailysOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosingStatisticDailysOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class DosingLogOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'col_names': 'list[str]',
        'times': 'list[datetime]',
        'values': 'list[list[str]]',
        'cal_value_acc': 'DailyAccumulationValue',
        'value_acc': 'DailyAccumulationValue'
    }

    attribute_map = {
        'col_names': 'colNames',
        'times': 'times',
        'values': 'values',
        'cal_value_acc': 'calValueAcc',
        'value_acc': 'valueAcc'
    }

    def __init__(self, col_names=None, times=None, values=None, cal_value_acc=None, value_acc=None, local_vars_configuration=None):  # noqa: E501
        """DosingLogOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._col_names = None
        self._times = None
        self._values = None
        self._cal_value_acc = None
        self._value_acc = None
        self.discriminator = None

        self.col_names = col_names
        self.times = times
        self.values = values
        if cal_value_acc is not None:
            self.cal_value_acc = cal_value_acc
        if value_acc is not None:
            self.value_acc = value_acc

    @property
    def col_names(self):
        """Gets the col_names of this DosingLogOutput.  # noqa: E501

        列名 column name  # noqa: E501

        :return: The col_names of this DosingLogOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._col_names

    @col_names.setter
    def col_names(self, col_names):
        """Sets the col_names of this DosingLogOutput.

        列名 column name  # noqa: E501

        :param col_names: The col_names of this DosingLogOutput.  # noqa: E501
        :type: list[str]
        """

        self._col_names = col_names

    @property
    def times(self):
        """Gets the times of this DosingLogOutput.  # noqa: E501

        所有时刻 all time steps  # noqa: E501

        :return: The times of this DosingLogOutput.  # noqa: E501
        :rtype: list[datetime]
        """
        return self._times

    @times.setter
    def times(self, times):
        """Sets the times of this DosingLogOutput.

        所有时刻 all time steps  # noqa: E501

        :param times: The times of this DosingLogOutput.  # noqa: E501
        :type: list[datetime]
        """

        self._times = times

    @property
    def values(self):
        """Gets the values of this DosingLogOutput.  # noqa: E501

        value of each column of each time step  # noqa: E501

        :return: The values of this DosingLogOutput.  # noqa: E501
        :rtype: list[list[str]]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this DosingLogOutput.

        value of each column of each time step  # noqa: E501

        :param values: The values of this DosingLogOutput.  # noqa: E501
        :type: list[list[str]]
        """

        self._values = values

    @property
    def cal_value_acc(self):
        """Gets the cal_value_acc of this DosingLogOutput.  # noqa: E501


        :return: The cal_value_acc of this DosingLogOutput.  # noqa: E501
        :rtype: DailyAccumulationValue
        """
        return self._cal_value_acc

    @cal_value_acc.setter
    def cal_value_acc(self, cal_value_acc):
        """Sets the cal_value_acc of this DosingLogOutput.


        :param cal_value_acc: The cal_value_acc of this DosingLogOutput.  # noqa: E501
        :type: DailyAccumulationValue
        """

        self._cal_value_acc = cal_value_acc

    @property
    def value_acc(self):
        """Gets the value_acc of this DosingLogOutput.  # noqa: E501


        :return: The value_acc of this DosingLogOutput.  # noqa: E501
        :rtype: DailyAccumulationValue
        """
        return self._value_acc

    @value_acc.setter
    def value_acc(self, value_acc):
        """Sets the value_acc of this DosingLogOutput.


        :param value_acc: The value_acc of this DosingLogOutput.  # noqa: E501
        :type: DailyAccumulationValue
        """

        self._value_acc = value_acc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosingLogOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosingLogOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class RiverPump(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pump_id': 'str',
        'control_wl': 'float',
        'capacity': 'float'
    }

    attribute_map = {
        'pump_id': 'pumpID',
        'control_wl': 'controlWL',
        'capacity': 'capacity'
    }

    def __init__(self, pump_id=None, control_wl=None, capacity=None, local_vars_configuration=None):  # noqa: E501
        """RiverPump - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pump_id = None
        self._control_wl = None
        self._capacity = None
        self.discriminator = None

        self.pump_id = pump_id
        if control_wl is not None:
            self.control_wl = control_wl
        if capacity is not None:
            self.capacity = capacity

    @property
    def pump_id(self):
        """Gets the pump_id of this RiverPump.  # noqa: E501


        :return: The pump_id of this RiverPump.  # noqa: E501
        :rtype: str
        """
        return self._pump_id

    @pump_id.setter
    def pump_id(self, pump_id):
        """Sets the pump_id of this RiverPump.


        :param pump_id: The pump_id of this RiverPump.  # noqa: E501
        :type: str
        """

        self._pump_id = pump_id

    @property
    def control_wl(self):
        """Gets the control_wl of this RiverPump.  # noqa: E501


        :return: The control_wl of this RiverPump.  # noqa: E501
        :rtype: float
        """
        return self._control_wl

    @control_wl.setter
    def control_wl(self, control_wl):
        """Sets the control_wl of this RiverPump.


        :param control_wl: The control_wl of this RiverPump.  # noqa: E501
        :type: float
        """

        self._control_wl = control_wl

    @property
    def capacity(self):
        """Gets the capacity of this RiverPump.  # noqa: E501


        :return: The capacity of this RiverPump.  # noqa: E501
        :rtype: float
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this RiverPump.


        :param capacity: The capacity of this RiverPump.  # noqa: E501
        :type: float
        """

        self._capacity = capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RiverPump):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RiverPump):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class QueryPipeDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'muid': 'str',
        'from_node': 'str',
        'to_node': 'str',
        'length': 'float',
        'diameter': 'float',
        'thickness': 'float',
        'pipe_status': 'int',
        'zone_id': 'str',
        'roughness': 'float',
        'loss_coeff': 'float',
        'material': 'str',
        'construction_year': 'datetime',
        'description': 'str',
        'data_source': 'str',
        'asset_name': 'str',
        'street_name': 'str',
        'from_x': 'float',
        'from_y': 'float',
        'to_x': 'float',
        'to_y': 'float',
        'operate': 'OperateEnum',
        'id': 'str'
    }

    attribute_map = {
        'muid': 'muid',
        'from_node': 'fromNode',
        'to_node': 'toNode',
        'length': 'length',
        'diameter': 'diameter',
        'thickness': 'thickness',
        'pipe_status': 'pipeStatus',
        'zone_id': 'zoneID',
        'roughness': 'roughness',
        'loss_coeff': 'lossCoeff',
        'material': 'material',
        'construction_year': 'constructionYear',
        'description': 'description',
        'data_source': 'dataSource',
        'asset_name': 'assetName',
        'street_name': 'streetName',
        'from_x': 'fromX',
        'from_y': 'fromY',
        'to_x': 'toX',
        'to_y': 'toY',
        'operate': 'operate',
        'id': 'id'
    }

    def __init__(self, muid=None, from_node=None, to_node=None, length=None, diameter=None, thickness=None, pipe_status=None, zone_id=None, roughness=None, loss_coeff=None, material=None, construction_year=None, description=None, data_source=None, asset_name=None, street_name=None, from_x=None, from_y=None, to_x=None, to_y=None, operate=None, id=None, local_vars_configuration=None):  # noqa: E501
        """QueryPipeDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._muid = None
        self._from_node = None
        self._to_node = None
        self._length = None
        self._diameter = None
        self._thickness = None
        self._pipe_status = None
        self._zone_id = None
        self._roughness = None
        self._loss_coeff = None
        self._material = None
        self._construction_year = None
        self._description = None
        self._data_source = None
        self._asset_name = None
        self._street_name = None
        self._from_x = None
        self._from_y = None
        self._to_x = None
        self._to_y = None
        self._operate = None
        self._id = None
        self.discriminator = None

        self.muid = muid
        self.from_node = from_node
        self.to_node = to_node
        if length is not None:
            self.length = length
        if diameter is not None:
            self.diameter = diameter
        if thickness is not None:
            self.thickness = thickness
        if pipe_status is not None:
            self.pipe_status = pipe_status
        self.zone_id = zone_id
        if roughness is not None:
            self.roughness = roughness
        if loss_coeff is not None:
            self.loss_coeff = loss_coeff
        self.material = material
        if construction_year is not None:
            self.construction_year = construction_year
        self.description = description
        self.data_source = data_source
        self.asset_name = asset_name
        self.street_name = street_name
        if from_x is not None:
            self.from_x = from_x
        if from_y is not None:
            self.from_y = from_y
        if to_x is not None:
            self.to_x = to_x
        if to_y is not None:
            self.to_y = to_y
        if operate is not None:
            self.operate = operate
        if id is not None:
            self.id = id

    @property
    def muid(self):
        """Gets the muid of this QueryPipeDto.  # noqa: E501

        模型中管段ID pipe muid  # noqa: E501

        :return: The muid of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._muid

    @muid.setter
    def muid(self, muid):
        """Sets the muid of this QueryPipeDto.

        模型中管段ID pipe muid  # noqa: E501

        :param muid: The muid of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._muid = muid

    @property
    def from_node(self):
        """Gets the from_node of this QueryPipeDto.  # noqa: E501

        起始节点 from node  # noqa: E501

        :return: The from_node of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._from_node

    @from_node.setter
    def from_node(self, from_node):
        """Sets the from_node of this QueryPipeDto.

        起始节点 from node  # noqa: E501

        :param from_node: The from_node of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._from_node = from_node

    @property
    def to_node(self):
        """Gets the to_node of this QueryPipeDto.  # noqa: E501

        终止节点 to node  # noqa: E501

        :return: The to_node of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._to_node

    @to_node.setter
    def to_node(self, to_node):
        """Sets the to_node of this QueryPipeDto.

        终止节点 to node  # noqa: E501

        :param to_node: The to_node of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._to_node = to_node

    @property
    def length(self):
        """Gets the length of this QueryPipeDto.  # noqa: E501

        管长 pipe length  # noqa: E501

        :return: The length of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this QueryPipeDto.

        管长 pipe length  # noqa: E501

        :param length: The length of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def diameter(self):
        """Gets the diameter of this QueryPipeDto.  # noqa: E501

        管径 pipe diameter  # noqa: E501

        :return: The diameter of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._diameter

    @diameter.setter
    def diameter(self, diameter):
        """Sets the diameter of this QueryPipeDto.

        管径 pipe diameter  # noqa: E501

        :param diameter: The diameter of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._diameter = diameter

    @property
    def thickness(self):
        """Gets the thickness of this QueryPipeDto.  # noqa: E501

        管壁厚度 pipe wall thickness  # noqa: E501

        :return: The thickness of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._thickness

    @thickness.setter
    def thickness(self, thickness):
        """Sets the thickness of this QueryPipeDto.

        管壁厚度 pipe wall thickness  # noqa: E501

        :param thickness: The thickness of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._thickness = thickness

    @property
    def pipe_status(self):
        """Gets the pipe_status of this QueryPipeDto.  # noqa: E501

        管道状态 pipe status  # noqa: E501

        :return: The pipe_status of this QueryPipeDto.  # noqa: E501
        :rtype: int
        """
        return self._pipe_status

    @pipe_status.setter
    def pipe_status(self, pipe_status):
        """Sets the pipe_status of this QueryPipeDto.

        管道状态 pipe status  # noqa: E501

        :param pipe_status: The pipe_status of this QueryPipeDto.  # noqa: E501
        :type: int
        """

        self._pipe_status = pipe_status

    @property
    def zone_id(self):
        """Gets the zone_id of this QueryPipeDto.  # noqa: E501

        分区ID zone id  # noqa: E501

        :return: The zone_id of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this QueryPipeDto.

        分区ID zone id  # noqa: E501

        :param zone_id: The zone_id of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._zone_id = zone_id

    @property
    def roughness(self):
        """Gets the roughness of this QueryPipeDto.  # noqa: E501

        粗糙度 pipe roughness  # noqa: E501

        :return: The roughness of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._roughness

    @roughness.setter
    def roughness(self, roughness):
        """Sets the roughness of this QueryPipeDto.

        粗糙度 pipe roughness  # noqa: E501

        :param roughness: The roughness of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._roughness = roughness

    @property
    def loss_coeff(self):
        """Gets the loss_coeff of this QueryPipeDto.  # noqa: E501

        损失系数 loss coefficient  # noqa: E501

        :return: The loss_coeff of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._loss_coeff

    @loss_coeff.setter
    def loss_coeff(self, loss_coeff):
        """Sets the loss_coeff of this QueryPipeDto.

        损失系数 loss coefficient  # noqa: E501

        :param loss_coeff: The loss_coeff of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._loss_coeff = loss_coeff

    @property
    def material(self):
        """Gets the material of this QueryPipeDto.  # noqa: E501

        管材 pipe material  # noqa: E501

        :return: The material of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._material

    @material.setter
    def material(self, material):
        """Sets the material of this QueryPipeDto.

        管材 pipe material  # noqa: E501

        :param material: The material of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._material = material

    @property
    def construction_year(self):
        """Gets the construction_year of this QueryPipeDto.  # noqa: E501

        建设时间 construction time  # noqa: E501

        :return: The construction_year of this QueryPipeDto.  # noqa: E501
        :rtype: datetime
        """
        return self._construction_year

    @construction_year.setter
    def construction_year(self, construction_year):
        """Sets the construction_year of this QueryPipeDto.

        建设时间 construction time  # noqa: E501

        :param construction_year: The construction_year of this QueryPipeDto.  # noqa: E501
        :type: datetime
        """

        self._construction_year = construction_year

    @property
    def description(self):
        """Gets the description of this QueryPipeDto.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QueryPipeDto.

        描述 description  # noqa: E501

        :param description: The description of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def data_source(self):
        """Gets the data_source of this QueryPipeDto.  # noqa: E501

        数据源 data source  # noqa: E501

        :return: The data_source of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._data_source

    @data_source.setter
    def data_source(self, data_source):
        """Sets the data_source of this QueryPipeDto.

        数据源 data source  # noqa: E501

        :param data_source: The data_source of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._data_source = data_source

    @property
    def asset_name(self):
        """Gets the asset_name of this QueryPipeDto.  # noqa: E501

        资产名称 asset name  # noqa: E501

        :return: The asset_name of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._asset_name

    @asset_name.setter
    def asset_name(self, asset_name):
        """Sets the asset_name of this QueryPipeDto.

        资产名称 asset name  # noqa: E501

        :param asset_name: The asset_name of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._asset_name = asset_name

    @property
    def street_name(self):
        """Gets the street_name of this QueryPipeDto.  # noqa: E501

        街道名称 street name  # noqa: E501

        :return: The street_name of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this QueryPipeDto.

        街道名称 street name  # noqa: E501

        :param street_name: The street_name of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def from_x(self):
        """Gets the from_x of this QueryPipeDto.  # noqa: E501

        起始节点坐标X coordinate x of from-node  # noqa: E501

        :return: The from_x of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._from_x

    @from_x.setter
    def from_x(self, from_x):
        """Sets the from_x of this QueryPipeDto.

        起始节点坐标X coordinate x of from-node  # noqa: E501

        :param from_x: The from_x of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._from_x = from_x

    @property
    def from_y(self):
        """Gets the from_y of this QueryPipeDto.  # noqa: E501

        起始节点坐标Y coordinate y of from-node  # noqa: E501

        :return: The from_y of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._from_y

    @from_y.setter
    def from_y(self, from_y):
        """Sets the from_y of this QueryPipeDto.

        起始节点坐标Y coordinate y of from-node  # noqa: E501

        :param from_y: The from_y of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._from_y = from_y

    @property
    def to_x(self):
        """Gets the to_x of this QueryPipeDto.  # noqa: E501

        终止节点坐标X coordinate x of to-node  # noqa: E501

        :return: The to_x of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._to_x

    @to_x.setter
    def to_x(self, to_x):
        """Sets the to_x of this QueryPipeDto.

        终止节点坐标X coordinate x of to-node  # noqa: E501

        :param to_x: The to_x of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._to_x = to_x

    @property
    def to_y(self):
        """Gets the to_y of this QueryPipeDto.  # noqa: E501

        终止节点坐标Y coordinate y of to-node  # noqa: E501

        :return: The to_y of this QueryPipeDto.  # noqa: E501
        :rtype: float
        """
        return self._to_y

    @to_y.setter
    def to_y(self, to_y):
        """Sets the to_y of this QueryPipeDto.

        终止节点坐标Y coordinate y of to-node  # noqa: E501

        :param to_y: The to_y of this QueryPipeDto.  # noqa: E501
        :type: float
        """

        self._to_y = to_y

    @property
    def operate(self):
        """Gets the operate of this QueryPipeDto.  # noqa: E501


        :return: The operate of this QueryPipeDto.  # noqa: E501
        :rtype: OperateEnum
        """
        return self._operate

    @operate.setter
    def operate(self, operate):
        """Sets the operate of this QueryPipeDto.


        :param operate: The operate of this QueryPipeDto.  # noqa: E501
        :type: OperateEnum
        """

        self._operate = operate

    @property
    def id(self):
        """Gets the id of this QueryPipeDto.  # noqa: E501

        管段ID pipe id  # noqa: E501

        :return: The id of this QueryPipeDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QueryPipeDto.

        管段ID pipe id  # noqa: E501

        :param id: The id of this QueryPipeDto.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryPipeDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryPipeDto):
            return True

        return self.to_dict() != other.to_dict()
